//Fichier d'include des objets de radarSmall_main.pov

	//Include devices computers at front of radar axe base
	#include "includes/obj_RadarControlSystem.inc"

//Tuning
#declare YDimParabole = 4;
#declare RayonRadar = 5.5;
#declare Segments = 24;
#declare PrismeEpaisseur = 0.25;
#declare DistIntoRadar = 1.5;//Old value 0.75
#declare RayonSphereCurve = ((RayonRadar * RayonRadar) + (DistIntoRadar * DistIntoRadar)) / (2 * DistIntoRadar);
#declare AngleRails = 43;//En degrs
#declare HauteurCone = 0.4;//Highness of cone at base of the rails
#declare LongueurRail = 5.25;
#declare RayonRailGlobal = 0.17;
#declare RayonTenant = 0.018;
#declare RayonPattes = 0.0075;
#declare DistEmpatte = 0.25;
#declare HauteurTronc = 3.2;
#declare DistConeReceptionOndes = 1.8 / 9 * LongueurRail;
#declare BlackRayTextureNum = 48;
#declare CenterHoleRadius = 0.68;

#declare BaseAntenneSegmentsNum = 16;
#declare AntCenterPyrHighness = 0.5;//Don't change it is for pyramid/ conic_sweep highness , change y scale just below instead
#declare AntCenterPyrYScale = 3.75;
#declare AntCenter2Highness = 0.85;

#declare ScrewMinOffset = 1 / 40;
#declare ScrewRay = 1 / 75;

//Ne pas modifier ci-dessous
#declare TransLongRail = HauteurCone + LongueurRail;
#declare RayonRail = TransLongRail * sin(radians(AngleRails) );//Distance entre l'axe vertical 0 et l'empattement du rail  sa base aprs rotation 
#declare LongRailWAngle = TransLongRail * cos(radians(AngleRails) );
#declare YbaseParabole = YDimParabole + PrismeEpaisseur - DistIntoRadar;
#declare newDelta = RayonRail / tan ( asin ( RayonRail / RayonSphereCurve) ); 
#declare TranslateAngleRails = YbaseParabole + RayonSphereCurve - newDelta; //Lorsque la base du rail est centre  0
#declare RayonConeReceptionOndes = DistConeReceptionOndes * RayonRail / LongRailWAngle - RayonRailGlobal;
#declare PosYConeRecepteurOndes = YbaseParabole + RayonSphereCurve - newDelta + LongRailWAngle - DistConeReceptionOndes;

//---------------------------------------------------------------
//Partie textures

#declare WhiteCol = color srgb 255/255;

#declare WhitePigFinish = finish{specular 0 roughness 0.0005 }

#declare BlackTexture = texture{pigment{ color srgb 0.45} finish{WhitePigFinish} }

#declare WhiteTexture = texture{ pigment{ WhiteCol } finish{WhitePigFinish} }

#declare WhitePigment = pigment{ WhiteCol }

#declare pig_rayon = pigment{ radial color_map{
											   [0.0 color srgbf 1 ]
											   [0.01 color srgbf 1 ]
											   [0.01 color srgb 0.6]
											   [0.03 color srgb 0.6]
											   [0.03 color srgbf 1 ]
											   [1.0 color srgbf 1 ]
											  }
							 frequency BlackRayTextureNum
							}
							
#declare pig_parabole_blueSpots = pigment{ image_map { png "images_maps/bluePtsTexture.png" 
														gamma srgb
														once 
														map_type 0 
														interpolate 2 
													 } 
											rotate 90*x translate <-0.5, 0, -0.5> scale RayonRadar*2
										 }
										 
#declare pig_parabole_graySpots = pigment{ image_map { png "images_maps/grayPtsTexture.png" 
														gamma srgb 
														once 
														map_type 0 
														interpolate 2 } 
											rotate 90*x translate <-0.5, 0, -0.5> scale RayonRadar*2
								  }
							
#declare RadarLeafTexture = texture{WhiteTexture}
							texture{pigment{pig_parabole_blueSpots} finish{specular 0.15 roughness 0.75 diffuse 0.9}  }
							texture{pigment{pig_rayon}}
							texture{pigment{pig_parabole_graySpots}	}

//------------------------------------------------
//Partie objets
#declare contenantCylindre = cylinder{<0,-32,0>,<0,32,0>, RayonRadar }
#declare SphereCurveDiff = sphere{<0, YDimParabole + PrismeEpaisseur - DistIntoRadar + RayonSphereCurve ,0 >, RayonSphereCurve  }
#declare FeuilleRadar =  difference{
                                     object{SphereCurveDiff }
                                     object{SphereCurveDiff translate 0.025 * y}
                                     object{contenantCylindre inverse}
                                     texture{ RadarLeafTexture}
                                   }

//Macro that easily creates points for 'DosRadarPrisme' and 'PyramideRadarPrisme'
#macro makePrismSegments(Rayon,SegmentsNum)
	//Segments selon l'axe y
	#local I = 0;
	#while(I < SegmentsNum)
		< vrotate(<0, 0, Rayon>, <0, 360/SegmentsNum*I,0>).x , 
		  vrotate(<0, 0, Rayon>, <0, 360/SegmentsNum*I,0>).z > 
		#local I = I + 1;
	#end
	//Closing prism
		< vrotate(<0, 0, Rayon>, <0, 360/SegmentsNum*0, 0>).x,
		  vrotate(<0, 0, Rayon>, <0, 360/SegmentsNum*0, 0>).z >
#end   

//Macro that creates screw on the border
#macro makeScrewOfTheBorder(Rayon)
    #local I = 0;
    #while(I < Segments)
        //Starting point:
        #local StartingPointBottom = vrotate(<0, 0, Rayon>, <0, 360/Segments*I, 0>);
        #local EndingPointBottom = vrotate(<0, 0, Rayon>, <0, 360/Segments*(I+1), 0>);
        #local ResultingVector = EndingPointBottom - StartingPointBottom;
        
        union{
        //Left screws
        sphere{ (StartingPointBottom + ScrewMinOffset * ResultingVector) + 7/8 * PrismeEpaisseur * y, ScrewRay } //Sphere A
        sphere{ (StartingPointBottom + ScrewMinOffset * ResultingVector) + 5.5/8 * PrismeEpaisseur * y, ScrewRay } //Sphere B
        sphere{ (StartingPointBottom + ScrewMinOffset * ResultingVector) + 2.5/8 * PrismeEpaisseur * y, ScrewRay } //Sphere C
        sphere{ (StartingPointBottom + ScrewMinOffset * ResultingVector) + 1/8 * PrismeEpaisseur * y, ScrewRay } //Sphere D
        
        //Center screws
        sphere{ (StartingPointBottom + ScrewMinOffset * 19 * ResultingVector) + 6.5 / 8 * PrismeEpaisseur * y, ScrewRay } //Sphere E
        sphere{ (StartingPointBottom + ScrewMinOffset * 19 * ResultingVector) + 5 / 8 * PrismeEpaisseur * y, ScrewRay } //Sphere F
        sphere{ (StartingPointBottom + ScrewMinOffset * 21 * ResultingVector) + 6.5 / 8 * PrismeEpaisseur * y, ScrewRay } //Sphere G
        sphere{ (StartingPointBottom + ScrewMinOffset * 21 * ResultingVector) + 5 / 8 * PrismeEpaisseur * y, ScrewRay } //Sphere H
        
        //RightScrews
        sphere{ (StartingPointBottom + ScrewMinOffset * 39 * ResultingVector) + 7/8 * PrismeEpaisseur * y, ScrewRay } //Sphere I
        sphere{ (StartingPointBottom + ScrewMinOffset * 39 * ResultingVector) + 5.5/8 * PrismeEpaisseur * y, ScrewRay } //Sphere J
        sphere{ (StartingPointBottom + ScrewMinOffset * 39 * ResultingVector) + 2.5/8 * PrismeEpaisseur * y, ScrewRay } //Sphere K
        sphere{ (StartingPointBottom + ScrewMinOffset * 39 * ResultingVector) + 1/8 * PrismeEpaisseur * y, ScrewRay } //Sphere L
            texture{ pigment{ color srgb 0.1 } finish{WhitePigFinish} }
        }
        #local I = I + 1;
    #end
#end                                 
                    
#declare DosRadarPrisme = prism{linear_spline linear_sweep 0, PrismeEpaisseur, Segments + 1, makePrismSegments(RayonRadar, Segments) }
#declare PyramideRadarPrisme = prism{ linear_spline conic_sweep 1, 0.25, Segments + 1, makePrismSegments(1, Segments) }

#declare AntenneCentrePyramide = prism{linear_spline conic_sweep 1, 1 - AntCenterPyrHighness, BaseAntenneSegmentsNum + 1, makePrismSegments(0.55, BaseAntenneSegmentsNum)}
#declare AntenneCentre2 = cylinder{<0,0,0>,<0, AntCenter2Highness, 0 >, 0.16 }
#declare AntenneCentre3 = cylinder{<0,0,0>,<0,0.4,0>,0.08}
#declare SphereJointureRails = difference{
								 sphere{<0,0,0>, RayonRailGlobal}
								 box{< -RayonRailGlobal, 0, -RayonRailGlobal>,< RayonRailGlobal, -2, RayonRailGlobal> }
							   }

#declare RadarParabole = union{
							difference{
								union{
									difference{
											merge{
												object{DosRadarPrisme translate 4*y texture{WhiteTexture}}
												object{PyramideRadarPrisme scale <RayonRadar, 4, RayonRadar> texture{WhiteTexture}} 		 
											}
											object{SphereCurveDiff texture{WhiteTexture}}		     
									}
									object{FeuilleRadar translate 0.005*y }		
								}
								cylinder{<0, YbaseParabole - 0.2, 0>,<0,YbaseParabole + 0.1, 0>, CenterHoleRadius texture{WhiteTexture} }//Crer trou pour antenne centrale
							}
                         union{
                             makeScrewOfTheBorder(RayonRadar)//The little screw on the border of the parabole (4 at the center and 4 on each side)
                             translate 4*y
                         }
							object{AntenneCentrePyramide rotate 180*x translate y scale <1,AntCenterPyrYScale,1> translate (YbaseParabole - 0.2)*y texture{WhiteTexture} }
							object{AntenneCentre2 translate (YbaseParabole -0.2 + AntCenterPyrYScale * AntCenterPyrHighness)*y texture{WhiteTexture} }
							object{AntenneCentre3 translate (YbaseParabole -0.2 + AntCenterPyrYScale * AntCenterPyrHighness + AntCenter2Highness)*y texture{WhiteTexture} }
						}
					

#declare CylindreRail = cylinder{<0,HauteurCone,RayonRailGlobal>,<0,HauteurCone + LongueurRail,RayonRailGlobal>, RayonTenant}                                 

#macro MakeOssatureRail()
    #local yPatte = HauteurCone + 0.15;
    #while(yPatte < HauteurCone + LongueurRail - DistEmpatte)
        cylinder{<0, yPatte + DistEmpatte, RayonRailGlobal >, vrotate(< 0, yPatte                , RayonRailGlobal >, <0,-120,0>), RayonPattes } 
        cylinder{<0, yPatte, RayonRailGlobal >,                 vrotate(< 0, yPatte + DistEmpatte, RayonRailGlobal >, <0, 120,0>), RayonPattes } 
        
        #local yPatte = yPatte + DistEmpatte;
    #end
#end
							  
#declare RailComplet = union{
                             cone{0, 0, HauteurCone*y, RayonRailGlobal + RayonPattes}
                             object{CylindreRail}
                             object{CylindreRail rotate 120*y}
                             object{CylindreRail rotate -120*y}
                             MakeOssatureRail()
                             texture{WhiteTexture}
                            }                                                  							  
              
#declare RadarFinal = union{
                            
                            object{RadarParabole}
                            object{ RailComplet translate -TransLongRail*y  rotate <0, 0, AngleRails > translate ( LongRailWAngle + TranslateAngleRails)*y}
                            object{ RailComplet translate -TransLongRail*y  rotate <0, 0, -AngleRails> translate ( LongRailWAngle + TranslateAngleRails)*y}
                            object{ RailComplet translate -TransLongRail*y  rotate <AngleRails, 0, 0 > translate ( LongRailWAngle + TranslateAngleRails)*y}
                            object{ RailComplet translate -TransLongRail*y  rotate <-AngleRails, 0, 0> translate ( LongRailWAngle + TranslateAngleRails)*y}
                            object{ SphereJointureRails translate (TranslateAngleRails + LongRailWAngle)*y  texture{WhiteTexture} }
                            cone{<0,PosYConeRecepteurOndes,0>, RayonConeReceptionOndes, <0,PosYConeRecepteurOndes - 0.4,0>,0 texture{WhiteTexture} }//Cone recepteur d'onde (coinc entre les rails  mi-chemin d'eux)
                           }    

             
#declare TroncSoutienRadarPrisme = prism{linear_spline linear_sweep 0.4, HauteurTronc, Segments + 1, makePrismSegments(1, Segments) }
#declare CylTronc1 = cylinder{<0,HauteurTronc,0>, <0,HauteurTronc + 0.4,0>, 0.9}
#declare CylTronc2 = cylinder{<0, HauteurTronc + 0.4 ,0>, <0, HauteurTronc + 1.2, 0>, 1.1}
#declare CylRotateParaboleSide = difference{ cylinder{< -0.15, HauteurTronc + 1.2, 0>,< 0.15, HauteurTronc + 1.2, 0>,1}
										 box{<-1,HauteurTronc + 0.6, -1>,<1,HauteurTronc + 1.2 - 1.1,1>}
									   }
									   
#declare CylTroncVis = cylinder{< 0, 0.25, 0>,< 0, 0.4, 0> , 0.9 }									   
#declare CylTroncVisAnneau = cylinder{<0,0.25,0>,<0,0.2,0> , 1 }	
#declare CylTroncNoirBase = cylinder{<0,0,0>,<0,0.2,0>, 1 }								   
									   
#declare CylRotateParaboleCenter = cylinder{<-0.1, 4.8, 0>, <0.1, 4.8, 0>, 1} 
									   

#declare BaseRadar = union{
						   object{CylTroncVisAnneau}
						   object{CylTroncVis}
						   object{TroncSoutienRadarPrisme}
						   object{CylTronc1}
						   object{CylTronc2}
						   object{CylTroncVis}
						   texture{WhiteTexture}
						  }
				
#declare VisBaseRadar = union{ 	
							  cylinder{<0,0,0>,<0,0.025,0>, 0.04} 
							  sphere{ <0,0.025,0>,0.025}
							  texture{BlackTexture}
						}

//The screws at the radar base (form a ring)						
#macro makeScrewRing(Rayon, VisBaseRadarNumber)
	#local I = 0;
	#while(I < VisBaseRadarNumber)
		object{VisBaseRadar translate <0, 0.25, Rayon> rotate (360/VisBaseRadarNumber*I) * y}
		#local I = I + 1;
	#end
	
#end     						
						  
#macro MakeRadar(positionRadar, rotateParabole, yAxe_devicesRotation)
	union{
		object{CylRotateParaboleSide translate -0.25*x rotate <0, rotateParabole.y, 0 > texture{WhiteTexture}} 
		object{CylRotateParaboleSide translate 0.25*x rotate <0, rotateParabole.y, 0> texture{WhiteTexture}} 
		object{CylRotateParaboleCenter rotate <0, rotateParabole.y, 0> texture{BlackTexture} }
		object{BaseRadar}
		object{CylTroncNoirBase texture{BlackTexture} }
		object{RadarFinal rotate 50*y rotate rotateParabole translate 5*y}
		object{ElectronicsDevices translate -1*z rotate yAxe_devicesRotation*y }
		makeScrewRing(0.95, 32)
	
		translate positionRadar
	}
#end						  