//Grass texture
//#declare PigGrass = pigment{srgb<0.45, 0.6, 0.25>} //{srgb <0.4, 1, 0.1>}
#declare TGrass = texture{pigment{srgb<94, 135, 63>/256} }

#declare RandGen = seed(79230);
#declare RandEp = seed(79000);//Seed for space grass blades
#declare RandColor = seed(1234);
#declare RandRotate = seed(5678);

#declare GBDk = <63, 82, 12>/256; //Grass blade Dark color
#declare GBLg = <109, 130, 67>/256; //Grass blade light color
#declare GCoefDir = < GBLg.x - GBDk.x, GBLg.y - GBDk.y , GBLg.z - GBDk.z>; //Grass col coef dir
 

//Place trees in the background line
//Trees in the background parameters
#declare eucalyptusCount = 81;
#declare delta = 4;
#declare vectPlace = <5 / delta, 0, 6 / delta>;
#declare startingPoint = < -20, -0.25, 0 > - vectPlace*12;

#declare MapleCount = 82;

#macro PlaceBackgroundMaples(offsetVector)
	#local MaplePos = startingPoint + /*<-8, 0 , 8>*/ + offsetVector;
	#local treesCount = 0;
	#while( treesCount < MapleCount )
		#if( !( MaplePos.x >= -20 & MaplePos.x <= -8 ) )
			object{MapleB2 rotate (360*rand(RandGen))*y scale <5, 5 + 4 * rand(RandGen) , 5> translate MaplePos} 
		#end
		#local treesCount = treesCount + 1;
		#local MaplePos = MaplePos + vectPlace;
	#end
#end

#macro PlaceDistantMaples(TreesNumber, offsetVector, spacingVector)
	#local MaplePos = startingPoint + offsetVector;
	#local TreesCount = 0;
	
	#while( TreesCount < TreesNumber )
		#if( !( MaplePos.x >= -20 & MaplePos.x <= -8 ) ) 
			object{MapleB2 rotate (360*rand(RandGen))*y scale <8, 8 + 4*rand(RandGen), 8> translate MaplePos}
		#end
		#local TreesCount = TreesCount + 1;
		#local MaplePos = MaplePos + spacingVector;
	#end
#end

//Place grass blade
	#declare Asw = <-32.5, 0, -15>;//Point triangulation south-west
	#declare Bn = <44, 0, 75>;//Point triangulation north
	#declare Cse = <26, 0, -35>; //Point triangulation south-east
	//GrassSquare
	#declare TopLeft = <-32.5, 0, 75>;
	#declare BottomRight = <42.5, 0, -35>;//Good value <42.5, 0, -35>
	#declare QuickBottomRight = <30, 0, -35>;
	#declare QuickTopLeft= <0, 0, 0>;
	
	#declare BladeDensity = 12; //2 * Per 1 unit square
	
//Tell if det > 0, at left side right side if det < 0 or on the line if d == 0 
#macro Determinant(ptA, ptB, ptTest, sideValue)
	#local LineVect = ptB - ptA;
	#local CrossVect = ptTest - ptA;
	#declare sideValue = LineVect.x * CrossVect.z - LineVect.z * CrossVect.x;
#end

#declare AllGround = union{object{TerrasseDur} 
					       object{SolTerreux}}

#declare GrassBladeFinish = finish{diffuse .8 specular .35 roughness 1e-2}

#macro PlaceGrass()
	#local GrassBladeCount = 0;
    #local Norm = <0, 0, 0>;
    #declare triangleSide1 = 0;
	#declare triangleSide2 = 0;
    #declare triangleSide3 = 0;
	
    #for(XCount, TopLeft.x, BottomRight.x )
		#for(ZCount, BottomRight.z, TopLeft.z )
			#for(InXBetween, -BladeDensity, BladeDensity - 1)
				#for(InZBetween, -BladeDensity, BladeDensity - 1)
					#local Start = < XCount + (InXBetween + rand(RandGen)) / (BladeDensity * 2), 1000, ZCount + (InZBetween + rand(RandGen)) / (BladeDensity * 2) >;
					#declare PosBlade = trace( AllGround, Start, -y, Norm );
					Determinant(Asw, Bn, PosBlade, triangleSide1)
					Determinant(Bn, Cse, PosBlade, triangleSide2) 
					Determinant(Cse, Asw, PosBlade, triangleSide3)
					#if ( PosBlade.y != 0.001 & triangleSide1 < 0 & triangleSide2 < 0 & triangleSide3 < 0 & rand(RandEp) > 0.5 )
						cylinder{0, <0, (0.025 + rand(RandGen)/25), 0>, 0.0085 scale <1,1,0.35> rotate <rand(RandRotate)*20-10 ,(360 * rand(RandGen) ), rand(RandRotate)*20-10> translate PosBlade 
							texture{pigment{color srgb<GCoefDir.x*rand(RandColor)+GBLg.x, GCoefDir.y*rand(RandColor)+GBLg.y, GCoefDir.z*rand(RandColor)+GBLg.z>} finish{ GrassBladeFinish }} }
					#local GrassBladeCount = GrassBladeCount + 1;
					#end
				#end
			#end
		#end
	#end
	#debug concat("Placed ", str(GrassBladeCount,0,0), " grass blades\n")
#end


