#version 3.8;

#declare UseRadiosity = true;
#declare RenderTrees = true;
#declare RenderTank = false;
#declare RenderJeep = true;
#declare RenderGrass = true;
#declare RenderIcoSphere = true;

#declare P_start = 64 / image_width;//With 1280 as image weight that yields : 0,05
#declare P_end_final = 4 / image_width;//With 1280 as image weight that yields : 0,003125

global_settings{ assumed_gamma 1.0
	#if( UseRadiosity )
		radiosity{
				pretrace_start P_start
				pretrace_end   P_end_final
				error_bound 0.1
				minimum_reuse 0.01
				nearest_count 9
				count 800
				recursion_limit 1
				always_sample off
				low_error_factor 0.5
				gray_threshold 0.65 //More than 0.5
				brightness 1
				normal on
				media on
		}
	#end
}

#default{ finish{ambient 0} }

camera{ 
	right x * image_width/image_height 
	up y
	location <26, 2, -35> 
	look_at <-5, 20, 20> 
	sky y
}

light_source{vrotate(< -3, 17, -13.75>* 240000, <0, 0,0>)  color srgb <1, 1, 0.95>*1.2 }

//The sky
#declare SkyPigment = pigment{ gradient y color_map{
													[0.0 color srgb <59, 89, 149> / 255 * 1.71 ]
													[0.75 color srgb <59, 89, 149> / 255 ]
													}
						}
						
sky_sphere{ pigment{SkyPigment} }
						
sphere{0, 1 
		pigment{ SkyPigment }
		finish{ diffuse 0 emission <1, 1, 0.95>*2.5 }
		scale 4000000 
		hollow on 
		no_shadow
		no_image
		no_reflection
}

#include "includes/backgroundSmallRadar.inc"

object{SolTerreux}
object{TerrasseDur}

#include "includes/objetsSmallRadar.inc"
MakeRadar(<20,0,-20>,  <-47,-50,0>,   0) //Radar le plus prs
MakeRadar(<22, 0, 30>, <-42, 0, 0>,     0) //Radar au fond  droite
MakeRadar(<-8, 0, -6>, <-50, -40, 0>, 0) //Radar au fond  gauche

#include "includes/objetsCrates.inc"
object{obj_Caisse scale 0.5 rotate -20*y translate <22,0, 0>}
object{obj_Caisse scale 0.5 rotate 10*y  translate <23,0, -2>}
object{obj_Caisse scale 0.5 translate <19,0, 0.5>}
object{CaisseMunition scale 0.75 translate <21, 0, -2>}
object{CaisseMunition scale 0.75 translate <18, 0, 2>}

#if( RenderTank )
	#include "abrams/char_abrams_POV_geom.inc"

	#declare ScaleTank = 6;
	#declare TankPos = <30, 0, 11>;
	object{TankM1Abrams rotate -130*y translate 0.192453*y scale ScaleTank translate TankPos}
#end

#if( RenderJeep )
	#include "jeep/Jeep_POV_geom.inc"
	#declare JeepPos = <30, 0, 11>;
	#declare JeepScale = 6 / 7 * 1.6;
	object{ Jeep rotate -138*y scale JeepScale translate JeepPos }
#end

#include "includes/placeTrees.inc"

#if( RenderTrees )
	#include "povtree/mapleB2.inc"

	PlaceBackgroundMaples(<0,0,0>)
	PlaceBackgroundMaples(<-8, 0, 8>)
	PlaceDistantMaples(14, <0, 0, 16>, vectPlace * 3)
#end

#if( RenderGrass )
	PlaceGrass()
#end

#if( RenderIcoSphere )
	#include "includes/icoSphereGeom.inc"
	
	//Scalar product of both background small radars:
	#local DirectionVect = <22, 0, 30> - <-8, 0, -6>;
	#local PushFartherVect = vnormalize( vrotate( DirectionVect, <0, -90, 0> ) ); 
	
	object{ IcoSphereRadar scale 5 translate <7, 0, 12> + PushFartherVect * 42 }
#end